"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var application_1 = require("@jupyterlab/application");
var coreutils_1 = require("@jupyterlab/coreutils");
var docmanager_1 = require("@jupyterlab/docmanager");
var filebrowser_1 = require("@jupyterlab/filebrowser");
var contents_1 = require("./contents");
var browser_1 = require("./browser");
require("../style/index.css");
/**
 * Google Drive filebrowser plugin state namespace.
 */
var NAMESPACE = 'github-filebrowser';
/**
 * The JupyterLab plugin for the GitHub Filebrowser.
 */
var fileBrowserPlugin = {
    id: 'jupyterlab-github:drive',
    requires: [docmanager_1.IDocumentManager, filebrowser_1.IFileBrowserFactory, application_1.ILayoutRestorer, coreutils_1.IStateDB],
    activate: activateFileBrowser,
    autoStart: true
};
/**
 * Activate the file browser.
 */
function activateFileBrowser(app, manager, factory, restorer, state) {
    var commands = app.commands;
    // Add the Google Drive backend to the contents manager.
    var drive = new contents_1.GitHubDrive(app.docRegistry);
    manager.services.contents.addDrive(drive);
    var browser = factory.createFileBrowser(NAMESPACE, {
        commands: commands,
        driveName: drive.name
    });
    var gitHubBrowser = new browser_1.GitHubFileBrowser(browser, drive);
    gitHubBrowser.title.iconClass = 'jp-GitHub-tablogo';
    gitHubBrowser.id = 'github-file-browser';
    // See if we have an user cached in the IStateDB.
    // Warning: there is a potential race condition here: if the filebrowser
    // tries to restore its directory before the user is reset, we will
    // overwrite that cwd. Otherwise we will not.
    var id = NAMESPACE;
    state.fetch(id).then(function (args) {
        var user = (args && args['user']) || '';
        gitHubBrowser.userName.name.set(user);
    });
    // Keep the IStateDB updated.
    gitHubBrowser.userName.name.changed.connect(function (sender, args) {
        state.save(id, { user: args.newValue });
    });
    // Add the file browser widget to the application restorer.
    restorer.add(gitHubBrowser, NAMESPACE);
    app.shell.addToLeftArea(gitHubBrowser, { rank: 102 });
    return;
}
exports.default = fileBrowserPlugin;
